@@ -16,13 +16,13 @@ ESS <- function(x)
      for (i in 1:ncol(x))
           {
           lm.out <- lm(x[, i] ~ z)
-          if (identical(all.equal(sd(residuals(lm.out)), 0), TRUE)) {
+          if(identical(all.equal(sd(residuals(lm.out)), 0), TRUE)) {
                v0[i] <- 0
                order[i] <- 0
                }
           else {
                ar.out <- ar(x[, i], aic = TRUE)
-               v0[i] <- ar.out$var.pred/(1 - sum(ar.out$ar))^2
+               v0[i] <- ar.out$var.pred / {1 - sum(ar.out$ar)}^2
                order[i] <- ar.out$order
                }
           }
